@@ -1,7 +1,7 @@
 package App::CompleteCLIs;
 
-our $DATE = '2020-08-02'; # DATE
-our $VERSION = '0.147'; # VERSION
+our $DATE = '2021-01-18'; # DATE
+our $VERSION = '0.148'; # VERSION
 
 use 5.010001;
 use strict;
@@ -22,7 +22,7 @@ App::CompleteCLIs - CLI wrappers for complete_*() functions
 
 =head1 VERSION
 
-This document describes version 0.147 of App::CompleteCLIs (from Perl distribution App-CompleteCLIs), released on 2020-08-02.
+This document describes version 0.148 of App::CompleteCLIs (from Perl distribution App-CompleteCLIs), released on 2021-01-18.
 
 =head1 SYNOPSIS
 
@@ -74,6 +74,8 @@ functions on the command-line.
 
 =item * L<complete-hash-key>
 
+=item * L<complete-idx-listed-stock-code>
+
 =item * L<complete-int>
 
 =item * L<complete-kernel>
@@ -154,7 +156,7 @@ Source repository is at L<https://github.com/perlancar/perl-App-CompleteCLIs>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-CompleteCLIs>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-App-CompleteCLIs/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -172,7 +174,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
